import os

__all__ = []

# For each file in directory
for filename in os.listdir(os.path.dirname(__file__)):

    # Get filename
    filename = os.path.basename(filename)

    # Check if is a python script
    if filename.endswith(".py") and not filename.startswith("__"):
        __all__.append(filename[:-3])

from . import *


from transformers import ViTFeatureExtractor, ViTForImageClassification, pipeline
from PIL import Image

class VisionClassifierInference:
    
  """
  🤗 Constructor for the image classifier trainer
  """
  def __init__(self, model_path: str, resolution=128):
    
    print("Load model from: " + model_path)
    self.feature_extractor = ViTFeatureExtractor.from_pretrained(model_path)
    self.model = ViTForImageClassification.from_pretrained(model_path)
    print("Model loaded!")
    
    self.resolution = resolution

  def predict(self, img_path: str):

    # Load the image
    image_array = Image.open(img_path)

    # Change resolution to 128x128
    image_array.thumbnail((self.resolution,self.resolution))

    # Transform the image
    encoding = self.feature_extractor(images=image_array, return_tensors="pt")

    # Predict and get the corresponding label identifier
    pred = self.model(encoding['pixel_values'])

    # Get label index
    predicted_class_idx = pred.logits.argmax(-1).tolist()[0]

    # Get string label from index
    label = self.model.config.id2label[predicted_class_idx]
    
    # print(pred.logits)
    
    return label



#!/usr/bin/env python3
import os
import setuptools
from distutils.core import setup

with open("README.md") as f:
    long_description = f.read()

with open(os.path.join("hugsvision", "version.txt")) as f:
    version = f.read().strip()

setup(
    name = "hugsvision",
    version = version,
    description = "A easy to use huggingface wrapper for computer vision.",
    long_description = long_description,
    long_description_content_type = "text/markdown",
    author = "Yanis Labrak & Others",
    author_email = "yanis.labrak@univ-avignon.fr",
    packages = setuptools.find_packages(),
    package_data = {
        "hugsvision": [
            "version.txt"
        ]
    },
    install_requires = [
        "torch",
        "torchvision",
        "torchmetrics",
        "Pillow",
        "scikit-learn",
        "transformers",
        "tqdm",
        "tabulate",
    ],
    python_requires = ">=3.6",
    url = "https://HugsVision.github.io/",
    keywords = ["python","transformers","huggingface","wrapper","toolkit","computer vision","easy","computer","vision"],
)